summaryrefslogtreecommitdiff
path: root/src/pathfinder/yapf/nodelist.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/pathfinder/yapf/nodelist.hpp')
-rw-r--r--src/pathfinder/yapf/nodelist.hpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/src/pathfinder/yapf/nodelist.hpp b/src/pathfinder/yapf/nodelist.hpp
index 87e65fd26..45a72efd5 100644
--- a/src/pathfinder/yapf/nodelist.hpp
+++ b/src/pathfinder/yapf/nodelist.hpp
@@ -42,7 +42,7 @@ public:
/** default constructor */
CNodeList_HashTableT() : m_open_queue(2048)
{
- m_new_node = NULL;
+ m_new_node = nullptr;
}
/** destructor */
@@ -65,7 +65,7 @@ public:
/** allocate new data item from m_arr */
inline Titem_ *CreateNewNode()
{
- if (m_new_node == NULL) m_new_node = m_arr.AppendC();
+ if (m_new_node == nullptr) m_new_node = m_arr.AppendC();
return m_new_node;
}
@@ -74,7 +74,7 @@ public:
{
/* for now it is enough to invalidate m_new_node if it is our given node */
if (&item == m_new_node) {
- m_new_node = NULL;
+ m_new_node = nullptr;
}
/* TODO: do we need to store best nodes found in some extra list/array? Probably not now. */
}
@@ -82,11 +82,11 @@ public:
/** insert given item as open node (into m_open and m_open_queue) */
inline void InsertOpenNode(Titem_ &item)
{
- assert(m_closed.Find(item.GetKey()) == NULL);
+ assert(m_closed.Find(item.GetKey()) == nullptr);
m_open.Push(item);
m_open_queue.Include(&item);
if (&item == m_new_node) {
- m_new_node = NULL;
+ m_new_node = nullptr;
}
}
@@ -96,7 +96,7 @@ public:
if (!m_open_queue.IsEmpty()) {
return m_open_queue.Begin();
}
- return NULL;
+ return nullptr;
}
/** remove and return the best open node */
@@ -107,10 +107,10 @@ public:
m_open.Pop(*item);
return item;
}
- return NULL;
+ return nullptr;
}
/** return the open node specified by a key or NULL if not found */
inline Titem_ *FindOpenNode(const Key &key)
{
Titem_ *item = m_open.Find(key);
@@ -129,11 +129,11 @@ public:
/** close node */
inline void InsertClosedNode(Titem_ &item)
{
- assert(m_open.Find(item.GetKey()) == NULL);
+ assert(m_open.Find(item.GetKey()) == nullptr);
m_closed.Push(item);
}
/** return the closed node specified by a key or NULL if not found */
inline Titem_ *FindClosedNode(const Key &key)
{
Titem_ *item = m_closed.Find(key);
@@ -107,10 +107,10 @@ public:
}
- /** return the open node specified by a key or NULL if not found */
+ /** return the open node specified by a key or nullptr if not found */
inline Titem_ *FindOpenNode(const Key &key)
{
@@ -129,11 +129,11 @@ public:
m_closed.Push(item);
}
- /** return the closed node specified by a key or NULL if not found */
+ /** return the closed node specified by a key or nullptr if not found */
inline Titem_ *FindClosedNode(const Key &key)
{